@@ -4,7 +4,7 @@
 # Copyright 2013 Giuseppe Venturini
 # This file is part of python-deltasigma.
 #
-# python-deltasigma is a 1:1 Python replacement of Richard Schreier's 
+# python-deltasigma is a 1:1 Python replacement of Richard Schreier's
 # MATLAB delta sigma toolbox (aka "delsigma"), upon which it is heavily based.
 # The delta sigma toolbox is (c) 2009, Richard Schreier.
 #
@@ -17,11 +17,13 @@
 """
 
 from __future__ import division
+
 import numpy as np
 from scipy.linalg import norm
 
 from ._dbp import dbp
 
+
 def logsmooth(X, inBin, nbin=8, n=3):
     """Smooth the fft, and convert it to dB.
 
@@ -111,17 +113,19 @@ def logsmooth(X, inBin, nbin=8, n=3):
     N = X.shape[0]
     N2 = int(np.floor(N/2))
     f1 = int(inBin % nbin)
-    startbin = np.concatenate((np.arange(f1, inBin, nbin), 
+    startbin = np.concatenate((np.arange(f1, inBin, nbin),
                                np.arange(inBin, inBin + 3)
                               ))
     i = 1 # my fix
     while i < n: # n can be big and xrange is not in Python3
-        startbin = np.concatenate((startbin, 
-                       np.arange(startbin[-1] + 1, (inBin + 1)*(i + 1) - 1, nbin), 
-                       (i + 1)*(inBin + 1) - 1 + np.arange(0, 3)
-                   ))
+        startbin = np.concatenate((startbin,
+                                   np.arange(startbin[-1] + 1,
+                                             (inBin + 1)*(i + 1) - 1, nbin),
+                                   (i + 1)*(inBin + 1) - 1 + np.arange(0, 3)
+                                  ))
         i = i + 1
-    startbin = np.concatenate((startbin, np.array((startbin[-1] + 1,)))) # my fix
+    # the following is my fix - REP?
+    startbin = np.concatenate((startbin, np.array((startbin[-1] + 1,))))
     m = startbin[-1] + nbin
     while m < N2 - 1:
         startbin = np.concatenate((startbin, np.array((m,))))
@@ -132,48 +136,6 @@ def logsmooth(X, inBin, nbin=8, n=3):
     f = ((startbin + stopbin)/2)/N
     p = np.zeros(f.shape)
     for i in range(f.shape[0]):
-        p[i] = dbp(norm(X[startbin[i]:stopbin[i] + 1])**2/(stopbin[i] - startbin[i] + 1))
+        p[i] = dbp(norm(X[startbin[i]:stopbin[i] + 1])**2/
+                   (stopbin[i] - startbin[i] + 1))
     return f, p
-
-def test_logsmooth():
-    """Test function for logsmooth()"""
-    import pkg_resources, scipy.io
-    from ._dbv import dbv
-    from ._ds_f1f2 import ds_f1f2
-    from ._ds_hann import ds_hann
-    from ._simulateDSM import simulateDSM
-    from ._synthesizeNTF import synthesizeNTF
-    from ._undbv import undbv
-    from numpy.fft import fft, fftshift
-    import numpy as np
-
-    f0 = 1./8
-    OSR = 64
-    order = 8
-    N = 8192
-    H = synthesizeNTF(order, OSR, 1, 1.5, f0)
-    fB = int(np.ceil(N/(2. * OSR)))
-    quadrature = False
-    M = 1
-    f1, f2 = ds_f1f2(OSR, f0, quadrature)
-    delta = 2
-    Amp = undbv(-3)
-    f1_bin = np.round(f1*N)
-    f2_bin = np.round(f2*N)
-    f = .3
-    fin = np.round(((1 - f)/2*f1 + (f + 1)/2 * f2) * N)
-    t = np.arange(0, N).reshape((1, -1))
-    u = Amp * M * np.cos((2*np.pi/N)*fin*t)
-    v, xn, xmax, y = simulateDSM(u, H, M + 1)
-
-    window = ds_hann(N)
-    NBW = 1.5/N
-    spec0 = fft(v * window) / (M*N/4)
-    freq = np.linspace(0, 0.5, N/2 + 1)
-
-    fl, pl = logsmooth(spec0, fin - 1) ### -1 is really important THIS IS NOT MATLAB!!
-
-    fname = pkg_resources.resource_filename(__name__, "test_data/test_logsmooth.mat")
-    data = scipy.io.loadmat(fname)
-    assert np.allclose(fl, data['fl'], atol=1e-8, rtol=1e-5)
-    assert np.allclose(pl, data['pl'], atol=1e-8, rtol=1e-5)
