@@ -4,7 +4,7 @@
 # Copyright 2013 Giuseppe Venturini
 # This file is part of python-deltasigma.
 #
-# python-deltasigma is a 1:1 Python replacement of Richard Schreier's 
+# python-deltasigma is a 1:1 Python replacement of Richard Schreier's
 # MATLAB delta sigma toolbox (aka "delsigma"), upon which it is heavily based.
 # The delta sigma toolbox is (c) 2009, Richard Schreier.
 #
@@ -16,8 +16,8 @@
 """Module providing the partitionABCD() function
 """
 
-def partitionABCD(ABCD, m=None):
-    """Partition ABCD into A, B, C, D for an m-input state-space system.
+def partitionABCD(ABCD, m=None, r=None):
+    """Partition ABCD into A, B, C, D for an m-input r-output system.
 
     The :math:`ABCD` matrix is defined as:
 
@@ -45,11 +45,14 @@ def partitionABCD(ABCD, m=None):
 
     The matrices are:
 
-    * :math:`A` is the state matrix, dimensions :math:`(n, n)`, :math:`n` being the number of states in the system,
+    * :math:`A` is the state matrix, dimensions :math:`(n, n)`, :math:`n` being
+      the number of states in the system,
 
-    * :math:`B` is the input matrix, dimensions :math:`(n, m)`, :math:`m` being the number of inputs in the system,
+    * :math:`B` is the input matrix, dimensions :math:`(n, m)`, :math:`m` being
+      the number of inputs in the system,
 
-    * :math:`C` is the output matrix, dimensions :math:`(r, n)`, :math:`r` being the number of outputs in the system,
+    * :math:`C` is the output matrix, dimensions :math:`(r, n)`, :math:`r`
+      being the number of outputs in the system,
 
     * :math:`D` is the feedthrough matrix, dimensions :math:`(r, m)`.
 
@@ -64,10 +67,15 @@ def partitionABCD(ABCD, m=None):
     **Parameters:**
 
     ABCD: ndarray
-          The ABCD matrix to be partitioned
+       The ABCD matrix to be partitioned
 
     m: int, optional
-       The number of inputs in the system. It will be calculated from the ABCD matrix if not provided.
+       The number of inputs in the system. It will be calculated from the ABCD matrix,
+       if not provided.
+
+    r: int, optional
+       The number of outputs in the system. It will be calculated from ``m`` and the
+       ABCD matrix, if not provided.
 
     **Returns:**
 
@@ -76,19 +84,31 @@ def partitionABCD(ABCD, m=None):
 
     .. seealso::
 
-        :ref:`Modulator model: loop filter <loop-filter-label>` for a discussion of the ABCD matrix in the particular case of a delta-sigma modulator loop filter.
+        :ref:`Modulator model: loop filter <loop-filter-label>` for a discussion of
+        the ABCD matrix in the particular case of a delta-sigma modulator loop filter.
 
     """
     # remember the ABCD matrix is assembled like this:
-    # [[A, B], 
+    # [[A, B],
     #  [C, D]]
     if m is None:
+        # we guess: the system has either one input or one output. Most
+        # likely one output, but we keep this for consistency with the
+        # MATLAB code.
         n = min(ABCD.shape) - 1
         m = ABCD.shape[1] - n
+        if r is None:
+            r = ABCD.shape[0] - n
     else:
         n = ABCD.shape[1] - m
+        if r is None:
+            r = ABCD.shape[0] - n
 
-    r = ABCD.shape[0] - n
+    if not ABCD.shape[0] == n+r and ABCD.shape[1] == n+m:
+        raise ValueError("Mismatched ABCD matrix and input/output counts:" +
+                         "ABCD: %dx%d, n: %d, m: %d, r: %d" % (ABCD.shape[0],
+                                                               ABCD.shape[1],
+                                                               n, m, r))
 
     A = ABCD[:n, :n]
     B = ABCD[:n, n:n+m]
